#!/bin/csh
##############################################################################
#This unix script convert a netcdf file in a CF1.1.
# CCMVal compatible netcdf file.
##############################################################################
# Contact:
# Irene Cionni (i.cionni@niwa.co.nz) and Veronika Eyring (veronika.eyring@dlr.de)
# http://www.pa.op.dlr.de/CCMVal/DataRequests/CCMVal-2_ExampleHeaders.html
##############################################################################
# Please check that the following programs are included in the run directory
# 
# attribute.ncl           : main ncl program
# global_attribute.ncl    : global attributes assignement function
# coord_function.ncl      : coordinates attributes function
# time_conform.ncl        : time conversion function
# att_function.ncl        : CCMVal variables attribute function 
#
# This script use  ncl   and netCDF Operators (NCO)
# http://www.ncl.ucar.edu
# http://nco.sourceforge.net/

##############################################################################
#               CHANGES ONLY IN PART A AND PART B                            #
##############################################################################
# PART A:                                                                    #
# provide information on the input file and on variable and coordinate names #
##############################################################################
# INPUT FILE NAME

 
  setenv CCMVal_field  'T2Mz'                      #Name of the CCMVal field of 
                                                 #as defined in the CCMVal Data
                                                 #Request (e.g. T2Ms, T3M etc).
  setenv inputdir      '/home/cionnii/REF2_OZONE/netcdf/'   #dir input name
  set    inputfile=ZONMEAN_O3_lath_1980to2050_SOCOL_1_REF2.nc
 #input file name 
  set    var=ZONMEAN           #input variable name    !!!NO SPACE BEFORE AND AFTER =
  set    lat_name=lat          #e.g. latitude
  set    lon_name=lon          #e.g. longitude
  set    lev_name=lev          #e.g. pressure
  set    time_name=time        #e.g. time

  echo $var   
  
##############################################################################
# PART B: provide information on the output file                             #
# Name of the output variable must to be consistent with the CCMVal Data     #
# Request                                                                    #
##############################################################################

  setenv  var_name    'O3'                    #name of the output variable as in CCMVal Data Request
  setenv  MODEL       'SOCOL'                #name of the model
  setenv  outputdir   ''/home/cionnii/REF2_OZONE/netcdf/" #name of the output directory
  setenv  source      'CCMVal. Method of production of the original data'                               
  setenv  contact     'J.McConnell, N.McFarlane, D.Plummer, J.Scinocca, T.Shepherd'
  setenv  REF         'REF-2'                # Name of the CCMVal-2 simulation
  setenv  exp_id      '1'                    # ID ensemble number 
  setenv  history     'List of the applications that have modified the original data'           
                                          # comment about of the history of the file 
  setenv  comment     'Miscellaneos information about the data or methods used to produce it'  
                                               #comment about the data 
##############################################################################
#!!!!!!!!!!!!!!!! NO CHANGES BELOW THIS LINE !!!!!!!!!!!!!!!!!!!!!           #
# PART C                                                                     #
##############################################################################
setenv references   'These files are created according to CF1.1 see  http://cf-pcmdi.llnl.gov/'   
echo $references
##############################################################################
setenv  fil_out   $outputdir'output_file.nc'
echo $fil_out
##############################################################################
##############################################################################
# this comand select the variable designed from the input file are present more than one variable 

ncks -O -v $var $inputdir$inputfile  $fil_out
  

#############################################################################
######### rename variable coordinate ########################################
#############################################################################

# rename the input coordinates as lat lon lev 
# if the coordinates have already the right name an error should be done
# but it doesn't compromise the run of the program  
#if you can improve this part retrieving  the errors please correct  and send me an email !!!!!  
 setenv  er   'IMPORTANT Error code -42 -46 -49  in NCO dont compromise the run '

ncrename -d .{$lat_name},lat $fil_out
 echo $er
ncrename -d .{$lon_name},lon $fil_out
 echo $er
ncrename -d .{$lev_name},lev $fil_out
 echo $er
ncrename -d .{$time_name},time $fil_out
 echo $er

ncrename -v .{$lat_name},lat $fil_out
 echo $er
ncrename -v .{$lon_name},lon $fil_out
 echo $er
ncrename -v .{$lev_name},lev $fil_out
 echo $er
ncrename -v .{$time_name},time $fil_out
 echo $er
#############################################################################
######### rename variable coordinate ########################################
#############################################################################

ncrename -v .{$var},$var_name $fil_out

#############################################################################
##################Change type of coordinates#################################

# ncap2 -O -s 'lat=double(lat)' $fil_out $fil_out
# echo $er
# ncap2 -O -s 'lon=double(lon)' $fil_out $fil_out
# echo $er
# ncap2 -O -s 'lev=double(lev)' $fil_out $fil_out
 
 ncap -O -s 'lat=double(lat)' $fil_out $fil_out
 echo $er
 ncap -O -s 'lon=double(lon)' $fil_out $fil_out
 echo $er
 ncap -O -s 'lev=double(lev)' $fil_out $fil_out
 echo $er
#############################################################################
#ncatted -O -a units,time,o,c,yyyymmdd $fil_out $fil_out
#ncap2 -O -s 'lev=lev/100'  $fil_out $fil_out
#############################################################################

ncl attribute.ncl   # call the ncl main progr

#############################################################################
rm  {$fil_out}*   #remove the transitory files
